RateLimitKeySpec class

Declarative key resolver configuration used by compileRateLimitPolicies.

Use RateLimitKeySpec.ip for a network identity or RateLimitKeySpec.header for an application-supplied identity such as a tenant ID. If a header specification is blank, compilation falls back to IP resolution.

Constructors

RateLimitKeySpec.header(String? header)
Creates a resolver specification based on header.
const
RateLimitKeySpec.ip()
Creates a resolver specification based on the request IP.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
The header name when kind is RateLimitKeyKind.header.
final
kind RateLimitKeyKind
The resolver strategy selected by this specification.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited