HeaderKeyResolver class
Resolves rate-limit identities from a request header.
The header value is used as-is when non-empty. Validate and normalize tenant or account identifiers before using them as a distributed key.
- Inheritance
-
- Object
- RateLimitKeyResolver
- HeaderKeyResolver
Constructors
- HeaderKeyResolver(String header)
-
Creates a header resolver for
header.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
RateLimitRequest request) → String? -
Returns the identity for
request, ornullwhen it cannot be resolved.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited